var a00506 =
[
    [ "com::sun::star::uno::Sequence&lt; E &gt;", "a01010.html", "a01010" ],
    [ "com::sun::star::uno::Sequence&lt; bool &gt;", "a01970.html", "a01970" ],
    [ "getCharSequenceCppuType", "a00506.html#a038ba0cd697dc610a1624bb991e20fa0", null ],
    [ "getCppuSequenceType", "a00506.html#a08259cf446584fca7772a769ff9274a7", null ],
    [ "getCppuType", "a00506.html#a71cc536653d0f2db090080b3d4ea90a1", null ],
    [ "com::sun::star::uno::toUnoSequence", "a00536.html#a05106795b49bd149a6487d14789b3264", null ]
];